#
# spec file for package efibootmgr
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           efibootmgr
Summary:        EFI Boot Manager
License:        GPL-2.0+
Group:          System/Boot
Version:        0.6.0
Release:        8.6
Url:            http://linux.dell.com/efibootmgr/
Source:         http://linux.dell.com/%{name}/%{name}-%{version}/%{name}-%{version}.tar.gz
Patch0:         %{name}-gcc-Wall.diff
Patch1:         %{name}-derhat.diff
Patch2:         %{name}-set_boot_order.diff
Patch3:         %{name}-fail-visibly.diff
Patch4:         %{name}-write-unique-id-once.diff
Patch5:         %{name}-check-boot-order.diff
Patch6:         %{name}-delete-multiple.diff
# FATE#320999: Memory Address Range Mirroring  (MARM)
Patch11:        MARM-add-m-and-M-options.diff
Patch12:        MARM-fix-insufficient-validation-check-of-M-option.diff
Patch13:        MARM-introduce-man-for-m-and-M-option.diff
Patch14:        MARM-extend-man-for-M-option.diff
Patch15:        MARM-sanitize-set_mirror.diff

BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  pciutils-devel
BuildRequires:  zlib-devel
ExclusiveArch:  ia64 x86_64 aarch64

%description
The EFI Boot Manager allows the user to edit the Intel Extensible
Firmware Interface (EFI) Boot Manager variables.  Additional
information about the EFI can be found at
<http://developer.intel.com/technology/efi/efi.htm>.

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch11 -p1
%patch12 -p1
%patch13 -p1
%patch14 -p1
%patch15 -p1

%build
LOADER="grub.efi"  # default loader
[ "$RPM_ARCH" != ia64 ] || LOADER="elilo.efi"  # except Itanium

case "%{_repository}" in
(openSUSE*)   VENDOR="openSUSE";;
(SLE_11_SP*)  VENDOR="SuSE"     LOADER="elilo.efi";;
(SUSE*|SLE*)  VENDOR="SUSE";;
(*)           VENDOR="linux";;
esac
make %{?_smp_mflags} EXTRA_CFLAGS="$RPM_OPT_FLAGS" \
	OS_VENDOR="$VENDOR" EFI_LOADER="$LOADER"

%install
install -d $RPM_BUILD_ROOT%{_sbindir}
make install BINDIR=$RPM_BUILD_ROOT%{_sbindir}
install -d $RPM_BUILD_ROOT%{_mandir}/man8
install -m 644 src/man/man8/efibootmgr.8 $RPM_BUILD_ROOT%{_mandir}/man8

%files
%defattr(-, root, root)
%doc README COPYING
%{_sbindir}/efibootmgr
%{_mandir}/man8/*.gz

%changelog
* Thu Jul 14 2016 rw@suse.com
- Add support for Memory Address Range Mirroring.
  [fate#320999, bsc#987599]
  (add MARM-add-m-and-M-options.diff,
  MARM-fix-insufficient-validation-check-of-M-option.diff,
  MARM-introduce-man-for-m-and-M-option.diff,
  MARM-extend-man-for-M-option.diff,
  MARM-sanitize-set_mirror.diff)
* Tue Sep 15 2015 rw@suse.com
- Properly latch long to short option for delete.  [bsc#945705]
  (efibootmgr-delete-multiple.diff)
* Fri Jul 24 2015 rw@suse.com
- Refresh for SLE12.  [bsc#929677]
  (efibootmgr-gcc-Wall.diff, efibootmgr-delete-multiple.diff)
* Wed Mar 11 2015 rw@suse.com
- Allow disk/partition as selector for delete as well.  [bsc#870211]
  (efibootmgr-delete-multiple.diff)
- Remove version number from patches.
  (add efibootmgr-derhat.diff, efibootmgr-fail-visibly.diff,
  efibootmgr-gcc-Wall.diff, efibootmgr-set_boot_order.diff,
  efibootmgr-write-unique-id-once.diff;
  drop efibootmgr-0.6.0-check-boot-order.diff,
  efibootmgr-0.6.0-delete-by-uuid.diff, efibootmgr-0.6.0-derhat.diff,
  efibootmgr-0.6.0-fail-visibly.diff, efibootmgr-0.6.0-gcc-Wall.diff,
  efibootmgr-0.6.0-set_boot_order.diff,
  efibootmgr-0.6.0-write-unique-id-once.diff)
* Fri Jan 30 2015 rw@suse.com
- Introduce partition UUID as selector for delete.  [bsc#870211]
  (efibootmgr-0.6.0-delete-by-uuid.diff)
* Tue Sep  9 2014 schwab@suse.de
- Enable for aarch64 (fate#318444)
* Mon Jul  7 2014 glin@suse.com
- Delete BootOrder if there is no more boot option.  [bnc#883545]
  (efibootmgr-0.6.0-check-boot-order.diff)
* Thu Dec 19 2013 rw@suse.com
- Update version number to 0.6.0,
- Integrate SLE11 patches.  [bnc#830784]
  (efibootmgr-0.6.0-fail-visibly.diff,
  efibootmgr-0.6.0-set_boot_order.diff)
- Fix gcc warnings.
  (efibootmgr-0.6.0-gcc-Wall.diff)
- Make default '--loader' build-time configurable.
  (efibootmgr-0.6.0-derhat.diff)
- Don't let '--write-signature' overwrite unique signatures.
  (efibootmgr-0.6.0-write-unique-id-once.diff)
- Drop obsolete patches
  (efibootmgr-0.5.4.diff,
  efibootmgr-0.5.4-catchup.diff,
  efibootmgr-0.5.4-sector-size.diff)
* Wed Mar 27 2013 rw@suse.com
- Print EFI status for failed '--create' as well.  [bnc#811767]
  (efibootmgr-0.5.4-fail-visibly.diff)
* Wed Mar 27 2013 rw@suse.com
- Fix '--bootorder' handling.  [bnc#810899]
  (efibootmgr-0.5.4-set_boot_order.diff)
- Print EFI status in case of failure.  [bnc#811767]
  (efibootmgr-0.5.4-fail-visibly.diff)
* Tue Feb 12 2013 rw@suse.com
- Apply critical upstream fixes
  o for memory leaking variable creation.  [bnc#746324]
  o to improve spec conformance by removing device path padding.
  o to work around broken Apple firmware.
  (efibootmgr-0.5.4-catchup.diff)
- Allow hard disk sector sizes not equal to 512.  [bnc#711830]
  (efibootmgr-0.5.4-sector-size.diff)
* Tue Jun 12 2012 mgorse@suse.com
- Add zlib-devel to BuildRequires
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant/obsolete tags/sections from specfile
  (cf. packaging guidelines)
* Wed Oct 15 2008 ro@suse.de
- added ExclusiveArch
* Thu Jul 31 2008 rw@suse.de
- Update to efibootmgr 0.5.4.  [FATE#301882]
* Fri Jan 18 2008 rw@suse.de
- Return non-zero exit code on errors. [#307965, FATE#302608]
* Tue Dec 19 2006 rw@suse.de
- Use '&' instead of '&&' to mask bits. [#219735]
- Fix compilation for STABLE.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Nov  9 2005 schwab@suse.de
- Update to efibootmgr 0.5.3.
* Mon Sep 19 2005 schwab@suse.de
- Update to efibootmgr 0.5.2.2.
* Wed Aug 10 2005 schwab@suse.de
- Update to efibootmgr 0.5.2 [#102441].
* Tue May 10 2005 schwab@suse.de
- Fix parsing of bus info for network boot entry [#82882].
* Wed Mar  9 2005 schwab@suse.de
- Update to efibootmgr 0.5.1.
* Thu Aug 26 2004 schwab@suse.de
- Update to efibootmgr 0.5.0.
* Wed Jun  9 2004 schwab@suse.de
- Update to efibootmgr 0.5.0-test4.
* Mon May  3 2004 schwab@suse.de
- Update to efibootmgr 0.5.0-test3.
* Fri Sep  5 2003 schwab@suse.de
- Update to efibootmgr 0.4.2.
* Wed Oct 23 2002 schwab@suse.de
- Update to efibootmgr 0.4.1.
* Sun May  5 2002 schwab@suse.de
- Update to efibootmgr 0.4.0.
* Fri Aug 10 2001 schwab@suse.de
- Update to efibootmgr 0.3.4.
* Wed May 23 2001 schwab@suse.de
- Update to efibootmgr 0.3.2.
* Tue May 22 2001 schwab@suse.de
- Fix uninitialized variable.
* Sat May 19 2001 schwab@suse.de
- Initial version 0.3.1.
